@@ -323,25 +323,20 @@
 <context>
     <name>DialogSessionOptions</name>
     <message>
-        <location filename="ViewSessionOptions.py" line="80"/>
+        <location filename="ViewSessionOptions.py" line="95"/>
         <source>QNetMan (Session options)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionOptions.py" line="81"/>
+        <location filename="ViewSessionOptions.py" line="96"/>
         <source>Marker</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionOptions.py" line="82"/>
+        <location filename="ViewSessionOptions.py" line="97"/>
         <source>Timestamp (vertcal line), min:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="ViewSessionOptions.py" line="83"/>
-        <source>RX / TX:</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>ListSessions</name>
@@ -494,157 +489,157 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="155"/>
+        <location filename="OptionsWindow.py" line="164"/>
         <source>Frequency of data collection:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="139"/>
+        <location filename="OptionsWindow.py" line="148"/>
         <source>10 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="140"/>
+        <location filename="OptionsWindow.py" line="149"/>
         <source>15 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="141"/>
+        <location filename="OptionsWindow.py" line="150"/>
         <source>20 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="142"/>
+        <location filename="OptionsWindow.py" line="151"/>
         <source>30 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="143"/>
+        <location filename="OptionsWindow.py" line="152"/>
         <source>40 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="144"/>
+        <location filename="OptionsWindow.py" line="153"/>
         <source>60 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="157"/>
+        <location filename="OptionsWindow.py" line="166"/>
         <source>Database time limit:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="127"/>
+        <location filename="OptionsWindow.py" line="136"/>
         <source>2 weeks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="128"/>
+        <location filename="OptionsWindow.py" line="137"/>
         <source>1 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="129"/>
+        <location filename="OptionsWindow.py" line="138"/>
         <source>2 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="130"/>
+        <location filename="OptionsWindow.py" line="139"/>
         <source>3 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="131"/>
+        <location filename="OptionsWindow.py" line="140"/>
         <source>4 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="132"/>
+        <location filename="OptionsWindow.py" line="141"/>
         <source>5 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="133"/>
+        <location filename="OptionsWindow.py" line="142"/>
         <source>6 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="134"/>
+        <location filename="OptionsWindow.py" line="143"/>
         <source>9 months</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="135"/>
+        <location filename="OptionsWindow.py" line="144"/>
         <source>1 year</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="136"/>
+        <location filename="OptionsWindow.py" line="145"/>
         <source>not limited</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="154"/>
+        <location filename="OptionsWindow.py" line="163"/>
         <source>DateTime format:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="145"/>
+        <location filename="OptionsWindow.py" line="154"/>
         <source>YYYY-MM-DD HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="146"/>
+        <location filename="OptionsWindow.py" line="155"/>
         <source>MM-DD-YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="147"/>
+        <location filename="OptionsWindow.py" line="156"/>
         <source>DD-MM-YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="148"/>
+        <location filename="OptionsWindow.py" line="157"/>
         <source>DD.MM.YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="149"/>
+        <location filename="OptionsWindow.py" line="158"/>
         <source>MM.DD.YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="150"/>
+        <location filename="OptionsWindow.py" line="159"/>
         <source>YYYY.MM.DD HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="151"/>
+        <location filename="OptionsWindow.py" line="160"/>
         <source>DD/MM/YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="152"/>
+        <location filename="OptionsWindow.py" line="161"/>
         <source>MM/DD/YYYY HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="153"/>
+        <location filename="OptionsWindow.py" line="162"/>
         <source>YYYY/MM/DD HH:MM:SS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="137"/>
+        <location filename="OptionsWindow.py" line="146"/>
         <source>Graphs colors:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="156"/>
+        <location filename="OptionsWindow.py" line="165"/>
         <source>RX</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="138"/>
+        <location filename="OptionsWindow.py" line="147"/>
         <source>TX</source>
         <translation type="unfinished"></translation>
     </message>
@@ -750,17 +745,17 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="158"/>
+        <location filename="OptionsWindow.py" line="167"/>
         <source>Enable root access ( restart needed )</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="126"/>
+        <location filename="OptionsWindow.py" line="135"/>
         <source>QNetMan (Settings)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindow.py" line="159"/>
+        <location filename="OptionsWindow.py" line="168"/>
         <source>Network interfaces</source>
         <translation type="unfinished"></translation>
     </message>
@@ -769,6 +764,11 @@ connections</source>
         <source>Anatoliy Kozlov</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="OptionsWindow.py" line="169"/>
+        <source>Language:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowExt</name>
@@ -873,32 +873,32 @@ Start daemons now ?</source>
 <context>
     <name>ViewSessionExt</name>
     <message>
-        <location filename="ViewSessionExt.py" line="211"/>
+        <location filename="ViewSessionExt.py" line="219"/>
         <source>h</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="212"/>
+        <location filename="ViewSessionExt.py" line="220"/>
         <source>m</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="213"/>
+        <location filename="ViewSessionExt.py" line="221"/>
         <source>s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="585"/>
+        <location filename="ViewSessionExt.py" line="648"/>
         <source>Comment on the session is saved</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="589"/>
+        <location filename="ViewSessionExt.py" line="652"/>
         <source>Comment on the session is removed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="593"/>
+        <location filename="ViewSessionExt.py" line="656"/>
         <source>Comment write error</source>
         <translation type="unfinished"></translation>
     </message>
