@@ -15,7 +15,7 @@ from mydb import MyDB
 
 class MainWindowExt( QtGui.QMainWindow ):
 	#pvr# def __init__(self, splash, parent = None):
-	def __init__(self, parent = None):
+	def __init__(self, qset, parent = None):
 		QtGui.QMainWindow.__init__( self, parent )
 		self.parent = parent
 		
@@ -54,7 +54,8 @@ class MainWindowExt( QtGui.QMainWindow ):
 		self.ui.setupUi( self )
 		
 		#настройки в конфигурационном файле
-		self.qset = QNMSettings.QNMSettings( myconfig.file_setting, self )
+		#self.qset = QNMSettings.QNMSettings( myconfig.file_setting, self )
+		self.qset = qset
 
 		self.windowRealTime = ViewCurrentSessionExt( self, self.db, self.mydbus, self.qset )
 		self.windowRealTime.hide()
@@ -94,7 +95,7 @@ class MainWindowExt( QtGui.QMainWindow ):
 
 	def showOptions(self):
 		if self.windowOptions == None:
-			self.windowOptions = OptionsWindowExt( self, self.db, self.mydbus )
+			self.windowOptions = OptionsWindowExt( self, self.db, self.mydbus, self.qset )
 		self.windowOptions.show()
 
 	def showConnections(self):
