@@ -7,12 +7,14 @@ from sys import path
 import myconfig
 from mydb import MyDB
 from DialogOptionsIfaceExt import DialogOptionsIfaceExt
+from MyNotify import MyNotify
 
 class OptionsWindowExt( QtGui.QMainWindow ):
-	def __init__(self, parent, mydb, mydbus ):
+	def __init__(self, parent, mydb, mydbus, qset ):
 		QtGui.QMainWindow.__init__(self, parent)
 		
 		self.mydbus = mydbus
+		self.qset = qset
 
 		try:
 			self.setAttribute( QtCore.Qt.WA_Maemo5StackedWindow )
@@ -26,6 +28,7 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 		self.ui = OptionsWindow.Ui_MainWindow()
 		self.ui.setupUi( self )
 
+		self.noti = MyNotify()
 
 		self.listFreqTraffDaemon = list()
 		self.listFreqTraffDaemon.append(10)
@@ -58,6 +61,11 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 		self.listLimitSizeDB.append(31104000)  #12
 		self.listLimitSizeDB.append(0)         #not limit
 
+		self.listLangauge = list()
+		self.listLangauge.append("Auto")
+		self.listLangauge.append("English")
+		self.listLangauge.append("Russian")
+
 		self.actionForm()
 
 	def actionForm(self):
@@ -99,6 +107,17 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 		self.ui.cB_root.stateChanged.connect( self.rootAccessOnOff )
 		self.rootAccessCheck()
 
+		for i in self.listLangauge:
+			self.ui.cB_language.addItem( i )
+		self.ui.cB_language.currentIndexChanged.connect( self.changeLanguage )
+		L = self.qset.language()
+		if L == "0":
+			self.ui.cB_language.setCurrentIndex( 0 )
+		elif L == "en":
+			self.ui.cB_language.setCurrentIndex( 1 )
+		elif L == "ru":
+			self.ui.cB_language.setCurrentIndex( 2 )
+
 
 	def changeFreqTraffDaemon(self, indx_changed):
 		sec = self.listFreqTraffDaemon[indx_changed]
@@ -165,3 +184,15 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 		self.dlgOptIf.show()
 		self.dlgOptIf.exec_()
 
+
+	#------------------------#
+	def changeLanguage( self, indx ):
+		if indx == 0: #auto
+			self.qset.setLanguage("0")
+		elif indx == 1: #english
+			self.qset.setLanguage("en")
+		elif indx == 2: #russian
+			self.qset.setLanguage("ru")
+		
+		#txt = "Restart QNetMan to change the language GUI"
+		#self.noti.notify( "%s"%txt )
