@@ -7,6 +7,9 @@ class QNMSettings(QtCore.QSettings):
 	def __init__(self, fileSetting, parent = None):
 		QtCore.QSettings.__init__( self, fileSetting, QtCore.QSettings.IniFormat, parent  )
 
+		self.groupMain = "main"
+		self.key_language = "language"
+
 		self.groupMonitorOpt = "monitor"
 		self.key_graphType = "graph_type"
 		self.key_showRule = "show_ruler"
@@ -26,6 +29,7 @@ class QNMSettings(QtCore.QSettings):
 		self.key_showTX_s = "show_tx"
 		self.key_timestamp_s = "timestamp"
 		self.key_zoom_s = "zoom"
+		self.key_graphType_s = "graph_type"
 
 		self.groupNetStat = "netstat"
 		self.key_autorefresh_ns = "autorefresh"
@@ -307,4 +311,56 @@ class QNMSettings(QtCore.QSettings):
 		val = val.toInt()
 		return val[0]
 
+
 	#----------------------------------#
+	def setTypeGraphStatSession( self ):
+		self.beginGroup( self.groupMonitorOpt )
+		self.setValue(self.key_graphType,"0")
+		self.endGroup()
+	
+	def setTypeGraphTimeSession( self ):
+		self.beginGroup( self.groupMonitorOpt )
+		self.setValue(self.key_graphType, "1")
+		self.endGroup()
+
+	def isTypeGrapStatSession(self):
+		self.beginGroup( self.groupMonitorOpt )
+		val = self.value( self.key_graphType, "0" )
+		self.endGroup()
+		if val == "0":
+			return True
+		else:
+			return False
+	
+	def isTypeGrapTimeSession(self):
+		self.beginGroup( self.groupMonitorOpt )
+		val = self.value( self.key_graphType, "1" )
+		self.endGroup()
+		if val == "1":
+			return True
+		else:
+			return False
+	
+	def typeGraphSession(self):
+		self.beginGroup( self.groupMonitorOpt )
+		val = self.value( self.key_graphType, "0" )
+		self.endGroup()
+		if val == "1":
+			return 1
+		else:
+			return 0
+	#----------------------------------#
+	
+	
+	#===============================================================#
+	def setLanguage(self, lang):
+		self.beginGroup( self.groupMain )
+		self.setValue(self.key_language, lang)
+		self.endGroup()
+
+	def language(self):
+		self.beginGroup( self.groupMain )
+		val = self.value( self.key_language, "0" )
+		self.endGroup()
+		val = val.toString()
+		return val
