@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-from PySide import QtGui, QtCore
+from PyQt4 import QtCore, QtGui
 
 LEFT2RIGHT = 0
 RIGHT2LEFT = 1
@@ -8,6 +8,9 @@ TOP2BOTTOM = 2
 BOTTOM2TOP = 3
 AUTOMATIC = 4
 
+QtCore.Signal = QtCore.pyqtSignal
+QtCore.Slot = QtCore.pyqtSlot
+
 class SlidingStackedWidget( QtGui.QStackedWidget ):
 	myAnimationFinished = QtCore.Signal()
 
