@@ -26,18 +26,7 @@ import sys
 QtCore.Signal = QtCore.pyqtSignal
 QtCore.Slot = QtCore.pyqtSlot
 
-class MyGraphicsScene( QtGui.QGraphicsScene ):
-	mousePressed = QtCore.Signal(int,int)
-	def __init__(self, parent = None):
-		QtGui.QGraphicsScene.__init__(self, parent)
-
-	def mousePressEvent( self, eventGrSc ):
-		p = eventGrSc.scenePos()
-		self.mousePressed.emit( p.x(), p.y() )
-
-		QtGui.QGraphicsScene.mousePressEvent( self, eventGrSc )
-
-	
+from MyGraphicsScene import MyGraphicsScene
 
 
 class ViewCurrentSessionExt( QtGui.QMainWindow ):
@@ -111,9 +100,11 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.Lx = self.lengthX-self.shiftX
 
 		self.X=0
-		self.scene = QtGui.QGraphicsScene()
-		##XXX##self.scene = MyGraphicsScene( self )
-		##XXX##self.scene.mousePressed.connect( self.sceneMousePress )
+		##XXX##self.scene = QtGui.QGraphicsScene()
+		##XXX##
+		self.scene = MyGraphicsScene( self )
+		##XXX##
+		self.scene.mousePressed.connect( self.sceneMousePress )
 
 		self.frm.graphicsView.setScene(self.scene)
 		self.frm.graphicsView.setSceneRect(0, 0, self.lengthX, self.lengthY)
@@ -425,7 +416,8 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.ui_dlgMO.setupUi( self.dlgMO )
 
 		self.ui_dlgMO.bGrGraphType.buttonPressed.connect( self.changeGrT )
-		##XXX##self.ui_dlgMO.cbRuler.stateChanged.connect( self.changeRuler )
+		##XXX##
+		self.ui_dlgMO.cbRuler.stateChanged.connect( self.changeRuler )
 		self.ui_dlgMO.pbTraffRX.toggled.connect( self.changeShowRX )
 		self.ui_dlgMO.pbTraffTX.toggled.connect( self.changeShowTX )
 		self.ui_dlgMO.sbTimestamp.valueChanged.connect( self.changeTimestamp )
@@ -541,11 +533,13 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		#включение линейки
 		if self.qset.isShowRuler():
-			##XXX##self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Checked )
+			##XXX##
+			self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Checked )
 			self.showMarker = True
 			self.qset.showRuler( True )
 		else:
-			##XXX##self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Unchecked )
+			##XXX##
+			self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Unchecked )
 			self.showMarker = False
 			self.qset.showRuler( False )
 
