@@ -113,6 +113,12 @@ class ViewSessionExt( QtGui.QMainWindow ):
 
 		#временные отметки
 		self.timestamp = self.qset.timestampSession()
+
+		#тип графика
+		#тип рисуемого графика
+		# 0 - статичтический вид
+		# 1 - временной вид
+		self.typeGraph = self.qset.typeGraphSession()
 		
 		self.actionForm()
 
@@ -120,7 +126,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.ui.pBshowOptins.clicked.connect( self.dialogSessionOptions )
 
 		self.ui.pBdialogComment.clicked.connect( self.dlgComment )
-		
+
 		self.ui.pBzoomIn.clicked.connect( self.zoomIn )
 		self.ui.pBzoomOut.clicked.connect( self.zoomOut )
 		if self.timeScale == 1:
@@ -154,6 +160,8 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.ui_dlgMO.pbTraffRX.toggled.connect( self.changeShowRX )
 		self.ui_dlgMO.pbTraffTX.toggled.connect( self.changeShowTX )
 		self.ui_dlgMO.sbTimestamp.valueChanged.connect( self.changeTimestamp )
+		
+		self.ui_dlgMO.bGrGraphType.buttonPressed.connect( self.changeGrT )
 
 
 	def setTimeSession(self, allSeconds, hour, min, sec):
@@ -363,33 +371,71 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		#отрисовка значений, входящего/исходящего трафика
 		x=0
 		j=0
-		#XXX: очисттка экрана от надписей перед прорисовкой
-		#self.scene.clear()
-		len_buf_traff = len( bufDeltaT )
-		while j < len_buf_traff:
-			#*#penRX.setWidth( bufDeltaT[j] )
-			#*#penTX.setWidth( bufDeltaT[j] )
+		if self.typeGraph == 0:
+			penRX = QtGui.QPen( self.colorRX )
+			penRX.setWidth( self.pxLenGraph )
+			penTX = QtGui.QPen( self.colorTX )
+			penTX.setWidth( self.pxLenGraph )
 
-			if self.showRX:
-				r = (self.Ly*(1.0 / maxScaleY))*bufRX[j]
-				#print "bufRX[%s]=%s;  r=%s"%(j,bufRX[j], r)
-				if r != 0:
-					#*#self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
-					rect = self.scene.addRect( x, self.Ly-r, bufDeltaT[j], r, penRX, brushRX )
-					#rect.setOpacity(0.8)
+			while j < len(bufRX):
+	
+				if self.showRX:
+					r = (self.Ly*(1.0 / maxScaleY))*bufRX[j]
+					self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
 
-			if self.showTX:
-				t = (self.Ly*(1.0 / maxScaleY))*bufTX[j]
-				#print "bufTX[%s]=%s;  t=%s"%(j,bufTX[j], t)
-				if t != 0:
-					#*#self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
-					rect = self.scene.addRect( x, self.Ly-t, bufDeltaT[j], t, penTX, brushTX )
-					#rect.setOpacity(0.8)
+				if self.showTX:
+					t = (self.Ly*(1.0 / maxScaleY))*bufTX[j]
+					self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
+	
+				x += self.pxLenGraph
+				j += 1
+		elif self.typeGraph == 1:
+			penRX = QtGui.QPen( self.colorRX )
+			penRX.setWidth( 2 )
+			penTX = QtGui.QPen( self.colorTX )
+			penTX.setWidth( 2 )
 
-			#print "%s --> x=%s (%s), r=%s t=%s"%(j,x,self.pxLenGraph, r, t)
-			#!#x += self.pxLenGraph
-			x += bufDeltaT[ j ]
-			j += 1
+			while j < (len(bufRX)-1):
+	
+				if self.showRX:
+					r1 = (self.Ly*(1.0 / maxScaleY))*bufRX[j+1]
+					r0 = (self.Ly*(1.0 / maxScaleY))*bufRX[j]
+					self.scene.addLine( x+dx, self.Ly-r0, x+dx+self.pxLenGraph, self.Ly-r1, penRX )
+
+				if self.showTX:
+					t1 = (self.Ly*(1.0 / maxScaleY))*bufTX[j+1]
+					t0 = (self.Ly*(1.0 / maxScaleY))*bufTX[j]
+					self.scene.addLine( x+dx, self.Ly-t0, x+dx+self.pxLenGraph, self.Ly-t1, penTX )
+	
+				x += self.pxLenGraph
+				j += 1
+#		#XXX: очисттка экрана от надписей перед прорисовкой
+#		#self.scene.clear()
+#		len_buf_traff = len( bufDeltaT )
+#		while j < len_buf_traff:
+#			#*#penRX.setWidth( bufDeltaT[j] )
+#			#*#penTX.setWidth( bufDeltaT[j] )
+#
+#			if self.showRX:
+#				r = (self.Ly*(1.0 / maxScaleY))*bufRX[j]
+#				#print "bufRX[%s]=%s;  r=%s"%(j,bufRX[j], r)
+#				if r != 0:
+#					#*#self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
+#					rect = self.scene.addRect( x, self.Ly-r, bufDeltaT[j], r, penRX, brushRX )
+#					#rect.setOpacity(0.8)
+#
+#			if self.showTX:
+#				t = (self.Ly*(1.0 / maxScaleY))*bufTX[j]
+#				#print "bufTX[%s]=%s;  t=%s"%(j,bufTX[j], t)
+#				if t != 0:
+#					#*#self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
+#					rect = self.scene.addRect( x, self.Ly-t, bufDeltaT[j], t, penTX, brushTX )
+#					#rect.setOpacity(0.8)
+#
+#			#print "%s --> x=%s (%s), r=%s t=%s"%(j,x,self.pxLenGraph, r, t)
+#			#!#x += self.pxLenGraph
+#			x += bufDeltaT[ j ]
+#			j += 1
 		
 		#отрисовка сетки и системы координат
 		self.drawSystemCoord()
@@ -521,6 +567,13 @@ class ViewSessionExt( QtGui.QMainWindow ):
 	
 	#-----------------#
 	def dialogSessionOptions(self):
+		#смена вида графика
+		if self.qset.isTypeGrapStatSession():
+			self.ui_dlgMO.rbTypeStat.setChecked( True )
+			self.typeGraph = 0
+		else:
+			self.ui_dlgMO.rbTypeTime.setChecked( True )
+			self.typeGraph = 1
 
 		#включение линейки
 		if self.qset.isShowMarkerSession():
@@ -552,6 +605,16 @@ class ViewSessionExt( QtGui.QMainWindow ):
 
 		self.dlgMO.show()
 		self.dlgMO.exec_()
+	
+	#изменение вида графика
+	def changeGrT(self, button):
+		if button == self.ui_dlgMO.rbTypeTime:
+			self.qset.setTypeGraphTimeSession()
+			self.typeGraph = 1
+		elif button == self.ui_dlgMO.rbTypeStat:
+			self.qset.setTypeGraphStatSession()
+			self.typeGraph = 0
+		self.drawGraph()
 
 	#изменение видимости линейки
 	def changeViewMarker(self, state ):
