@@ -149,9 +149,6 @@ class WinNetStatExt( QtGui.QMainWindow ):
 #			pass
 		#------------------------------------#
 
-		self.flPacket = "tcp"
-		self.ui.pb_tcp.setChecked( True )
-		
 		self.w_refresh.hide()
 		self.pb_wait_refresh.clicked.connect( self.pleaseWait )
 		
@@ -208,6 +205,12 @@ class WinNetStatExt( QtGui.QMainWindow ):
 		self.listConn.setItemDelegate( plugin )
 
 		self.ui_procInfo.lblDescrText.setFontPointSize(12)
+
+	#функция для первого вызова при создании объекта
+	#после того, как вызвали show()
+	def initData(self):
+		self.flPacket = "tcp"
+		self.ui.pb_tcp.setChecked( True )
 	
 	
 	def defineColor(self):
