@@ -294,13 +294,18 @@ class MyDB:
 	# возвращает список сессий за указанный период времени и типу трафика
 	def getListSession(self, type_session, start_time=None, end_time=None):
 		if start_time != None and end_time != None:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s' AND stop < '%s'"%( type_session, start_time, end_time )
+			#SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s' AND stop < '%s'"%( type_session, start_time, end_time )
+			SQL = "SELECT `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND type_id=%s AND start > '%s' AND stop < '%s'"%( type_session, start_time, end_time )
 		elif start_time != None and end_time == None:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s'"%( type_session, start_time )
+			#SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND start > '%s'"%( type_session, start_time )
+			SQL = "SELECT `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND type_id=%s AND start > '%s'"%( type_session, start_time )
 		elif start_time == None and end_time != None:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND stop < '%s'"%( type_session, end_time )
+			#SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s AND stop < '%s'"%( type_session, end_time )
+			SQL = "SELECT `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND type_id=%s AND stop < '%s'"%( type_session, end_time )
 		else:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s"%type_session
+			#SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND type_id=%s"%type_session
+			SQL = "SELECT `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND type_id=%s"%type_session
+			print SQL
 		
 		listReturn = []
 		try:
@@ -311,6 +316,7 @@ class MyDB:
 				session["start"] = row[1]
 				session["stop"] = row[2]
 				session["type_session"] = row[3]
+				session["comment"] = row[4]
 				listReturn.append(session)
 				j += 1
 		except Exception, E:
@@ -322,13 +328,13 @@ class MyDB:
 	# возвращает список сессий за указанный период времени без типа трафика
 	def getFullListSession(self, start_time=None, end_time=None):
 		if start_time != None and end_time != None:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND start > '%s' AND stop < '%s'"%( start_time, end_time )
+			SQL = "select `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND start > '%s' AND stop < '%s'"%( start_time, end_time )
 		elif start_time != None and end_time == None:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND start > '%s'"%( start_time )
+			SQL = "select `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND start > '%s'"%( start_time )
 		elif start_time == None and end_time != None:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL AND stop < '%s'"%( end_time )
+			SQL = "select `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL AND stop < '%s'"%( end_time )
 		else:
-			SQL = "select `id`,`start`,`stop`,`type_id` FROM 'main'.'session' WHERE stop NOT NULL"
+			SQL = "select `session`.`id`, `session`.`start`, `session`.`stop`, `session`.`type_id`, `cs`.`comment` FROM 'main'.'session' LEFT JOIN `commentsession` AS `cs` ON `cs`.`session_id` == `session`.`id` WHERE stop NOT NULL"
 		
 		listReturn = []
 		try:
@@ -339,6 +345,7 @@ class MyDB:
 				session["start"] = row[1]
 				session["stop"] = row[2]
 				session["type_session"] = row[3]
+				session["comment"] = row[4]
 				listReturn.append(session)
 				j += 1
 		except Exception, E:
