@@ -26,11 +26,15 @@ from socket import socket, SOCK_DGRAM, AF_INET, inet_ntoa
 from fcntl import ioctl
 from struct import pack
 
-#import time
+import time
+from string import split
 
 
-VERSION = "0.3.0"
+VERSION = "0.6.0"
+##############################################
 
+MODE_MONITOR = 0
+MODE_COUNT = 1
 
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
@@ -57,6 +61,7 @@ class Config(SingleObject):
 	path_vis_net_iface = path + "/network_interfaces"
 	path_show_ip = path + "/show_ip"
 	path_show_rec = path + "/show_rec_button"
+	path_mode = path + "/mode"
 	
 	observers = []
 
@@ -87,30 +92,60 @@ class Config(SingleObject):
 		#t2 = time.time()
 		#print "Update took: %f seconds" % (t2-t1)
 	
+	#интервал обновления
 	def set_refresh_interval(self, value):
 		self.client.set_int( self.path_refr_int, value )
 	
 	def get_refresh_interval(self):
 		return self.client.get_int( self.path_refr_int )
 
+	#список отображаемых сетевых интерфейсов
 	def set_show_iface(self,value):
 		self.client.set_list( self.path_vis_net_iface, gconf.VALUE_STRING, value )
 	
 	def get_show_iface( self ):
 		return self.client.get_list( self.path_vis_net_iface, gconf.VALUE_STRING )
 
+	#скрыть/показать IP адрес
 	def set_show_ip(self, value):
 		self.client.set_bool( self.path_show_ip, value )
 	
 	def get_show_ip(self):
 		return self.client.get_bool( self.path_show_ip )
 
+	# показать/отключить кнопки записи
 	def set_show_rec(self, value):
 		self.client.set_bool( self.path_show_rec, value )
 	
 	def get_show_rec(self):
 		return self.client.get_bool( self.path_show_rec )
 
+	# счетчик по каждому сетевому интерфейсу
+	def set_value_count(self, key, value):
+		#print "%s => %s"%(key, value)
+		key = self.path + key
+		self.client.set_string( key, "%s"%value )
+
+	def get_value_count(self, key):
+		key = self.path + key
+		val = self.client.get_string( key )
+		if val == None:
+			val = 0
+		else:
+			try:
+				val = long( "%s"%val, 10 )
+			except:
+				pass
+		return val
+	
+	#режим виджета (0-монитор; 1-счетчик)
+	def set_mode_widget(self, value):
+		self.client.set_int( self.path_mode, value )
+	
+	def get_mode_widget(self):
+		return self.client.get_int( self.path_mode )
+
+
 
 
 class CustomButton(hildon.Button):
@@ -212,6 +247,12 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		self.showIP = self.myconfig.get_show_ip()
 		self.showButtonRec = self.myconfig.get_show_rec()
 		self.listShowIface = self.myconfig.get_show_iface()
+		self.mode = self.myconfig.get_mode_widget()
+		
+		#--- параметры для счетчика ---#
+		self.rx0 = 0
+		self.tx0 = 0
+		self.title_button_reset = "Reset the counter of bytes on "
 
 		self.listIface = []
 		self.listIface.append("gprs0")
@@ -222,9 +263,16 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		self.listIface.append("ppp0")
 
 
+		#self.num_show_ifaces = 0
 		if len(self.listShowIface) == 0:
 			self.listShowIface.append("gprs0")
 			self.myconfig.set_show_iface( self.listShowIface )
+			#self.num_show_ifaces = 1
+
+
+		self.listModeWidget = []
+		self.listModeWidget.append("Monitoring mode")
+		self.listModeWidget.append("Counter mode")
 		
 
 		self.listRefreshInterval = []
@@ -304,6 +352,7 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		self.add(eventBox)
 		
 		self.updateMyWidget()
+		
 
     
 	#--- перехватчики событий кликов на виджете ---#
@@ -354,6 +403,14 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 
 		img_iface = self.pictureIface( iface )
 		hbox.pack_start(img_iface, False, True, 0)
+
+		img_rx = gtk.Image()
+		img_rx.set_from_file( "/usr/share/icons/hicolor/24x24/hildon/general_received.png" )
+		img_tx = gtk.Image()
+		img_tx.set_from_file( "/usr/share/icons/hicolor/24x24/hildon/general_sent.png" )
+		
+		l = gtk.Label(" ")
+		hbox.pack_start( l, False, True, 0 )
 		
 		if self.showIP:
 			label_rx = self.my_label_color_small()
@@ -372,9 +429,9 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 			
 			self.bufLabelTraff[ iface+"_label_ip" ] = label_ip
 			
-			#hbox_ip_up.pack_start( img_rx, False, True, 0 )
+			hbox_ip_up.pack_start( img_rx, False, True, 0 )
 			hbox_ip_up.pack_start(label_rx, True, False, 0) #!
-			#hbox_ip_up.pack_start( img_tx, False, True, 0 )
+			hbox_ip_up.pack_start( img_tx, False, True, 0 )
 			hbox_ip_up.pack_start(label_tx, True, False, 0) #!
 
 			v_ip.pack_start(hbox_ip_up, True, False, 0)
@@ -388,13 +445,18 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 			self.bufLabelTraff[ iface+"_label_rx" ] = label_rx
 			self.bufLabelTraff[ iface+"_label_tx" ] = label_tx
 
-			#hbox.pack_start( img_rx, False, True, 0 )
+			hbox.pack_start( img_rx, False, True, 0 )
 			hbox.pack_start(label_rx, True, False, 0) #!
-			#hbox.pack_start( img_tx, False, True, 0 )
+			hbox.pack_start( img_tx, False, True, 0 )
 			hbox.pack_start(label_tx, True, False, 0) #!
 
-		#self.bufLabelTraff[ iface+"_image_rx" ] = img_rx
-		#self.bufLabelTraff[ iface+"_image_tx" ] = img_tx
+		self.bufLabelTraff[ iface+"_image_rx" ] = img_rx
+		self.bufLabelTraff[ iface+"_image_tx" ] = img_tx
+		
+		self.bufLabelTraff[ iface+"_rx_curr" ] = 0
+		self.bufLabelTraff[ iface+"_tx_curr" ] = 0
+		self.bufLabelTraff[ iface+"_rx_prev" ] = 0
+		self.bufLabelTraff[ iface+"_tx_prev" ] = 0
 
 		try:
 			status_record_iface = self.qnetman_dbus_client.recStatus( iface )
@@ -430,11 +492,11 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		#cr.clip()
 		
 		rect = self.get_allocation()
-
 		x = rect.x
 		y = rect.y
 		width = rect.width
 		height = rect.height
+		#print "x=%s y=%s width=%s height=%s"%(x,y,width,height)
 
 		cr.new_sub_path()
 		cr.arc(x + width - radius, y + radius, radius, -90 * degrees, 0 * degrees)
@@ -486,34 +548,98 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 
 	#обновление информации на виджете
 	def updateMyWidget(self):
+		num_ifaces = 0
 		for iface in self.listShowIface:
 			if ( (self.bufLabelTraff.has_key( iface + "_label_rx" )) and (self.bufLabelTraff.has_key( iface + "_label_tx" )) ):
 				label_rx = self.bufLabelTraff[ iface + "_label_rx" ]
 				label_tx = self.bufLabelTraff[ iface + "_label_tx" ]
+				rx_curr = self.bufLabelTraff[ iface + "_rx_curr" ]
+				tx_curr = self.bufLabelTraff[ iface + "_tx_curr" ]
+				rx_prev = self.bufLabelTraff[ iface + "_rx_prev" ]
+				tx_prev = self.bufLabelTraff[ iface + "_tx_prev" ]
 
-				if self.showIP:
-					ip_addr = self.getip_iface( iface )
-					self.bufLabelTraff[ iface + "_label_ip" ].set_text( ip_addr )
+				num_ifaces += 1
 
 				rx, tx, ok = self.getTraff(iface)
-				if ok:
-					rx = self.humanBytes( rx )
-					tx = self.humanBytes( tx )
-					label_rx.set_text("  RX: %s "%rx)
-					label_tx.set_text("  TX: %s "%tx)
-					#label_rx.set_text(" %s "%rx)
-					#label_tx.set_text(" %s "%tx)
+
+#----- РЕЖИМ СЧЕТЧИКА
+				if self.mode == MODE_COUNT:
+					if( (rx_prev == 0) and (tx_prev == 0) and (ok==True) ):
+						rx_prev = rx
+						tx_prev = tx
+						rx_curr = rx
+						tx_curr = tx
+
+					self.bufLabelTraff[ iface + "_rx_curr" ] = rx
+					self.bufLabelTraff[ iface + "_tx_curr" ] = tx
+					rx_curr = rx
+					tx_curr = tx
+					drx = rx_curr - rx_prev
+					dtx = tx_curr - tx_prev
+					#print iface, rx_curr, rx_prev, drx
+					#print iface, tx_curr, tx_prev, dtx
+
+					if drx < 0:
+						drx = rx
+						dtx = tx
+					rx_count = self.countByteRX( iface ) + drx
+					tx_count = self.countByteTX( iface ) + dtx
+					rx = self.humanBytes( rx_count )
+					tx = self.humanBytes( tx_count )
+					if ok:
+						label_rx.set_text( " %s "%rx )
+						label_tx.set_text( " %s "%tx )
+						if self.showIP:
+							ip_addr = self.getip_iface( iface )
+							self.bufLabelTraff[ iface + "_label_ip" ].set_text( ip_addr )
+						
+						self.saveByteRX( iface, rx_count )
+						self.saveByteTX( iface, tx_count )
+					else:
+						label_rx.set_text( " %s "%rx )
+						label_tx.set_text( " %s "%tx )
 					
-					#self.bufLabelTraff[ iface + "_image_rx" ].show()
-					#self.bufLabelTraff[ iface + "_image_tx" ].show()
-				else:
-					label_rx.set_text(" OFFLINE ")
-					label_tx.set_text("")
+						if self.showIP:
+							ip_addr = self.getip_iface( iface )
+							self.bufLabelTraff[ iface + "_label_ip" ].set_text( "offline" )
+
+					self.bufLabelTraff[ iface + "_rx_prev" ] = rx_curr
+					self.bufLabelTraff[ iface + "_tx_prev" ] = tx_curr
+
+#----- РЕЖИМ АКТИВНОСТИ ИНТЕРФЕЙСОВ
+				elif self.mode == MODE_MONITOR:
+					if ok:
+						rx = self.humanBytes( rx )
+						tx = self.humanBytes( tx )
+						#label_rx.set_text("  RX: %s "%rx)
+						#label_tx.set_text("  TX: %s "%tx)
+						label_rx.set_text(" %s "%rx)
+						label_tx.set_text(" %s "%tx)
 					
-					#self.bufLabelTraff[ iface + "_image_rx" ].hide()
-					#self.bufLabelTraff[ iface + "_image_tx" ].hide()
+						if self.showIP:
+							ip_addr = self.getip_iface( iface )
+							self.bufLabelTraff[ iface + "_label_ip" ].set_text( ip_addr )
+					else:
+						label_rx.set_text(" 0.00 kB ")
+						label_tx.set_text(" 0.00 kB ")
+					
+						if self.showIP:
+							ip_addr = self.getip_iface( iface )
+							self.bufLabelTraff[ iface + "_label_ip" ].set_text( "offline" )
+#-----
 		if self.refresh_interval_seconds != 0:
 			self.id_timeout = gobject.timeout_add_seconds( self.refresh_interval_seconds, self.updateMyWidget )
+		#self.num_show_ifaces = num_ifaces
+		
+		#h = 50*self.num_show_ifaces
+		h = 50*num_ifaces
+		w = 310
+		if self.showButtonRec:
+			w += 64
+		if self.showIP:
+			w -= 40
+		self.set_size_request( w, h )
+
 		#print
 	
 
@@ -532,13 +658,47 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		elif bytes > 1024:
 			strRet = "%.2f kB"%( bytes/1024.0 )
 		else:
-			strRet = "%s B"%( bytes )
+			strRet = "%.2f B"%( bytes )
 		return strRet
 
 
+	#------- запись значения в байтах в gconf -------#
+	def saveByteRX( self, iface, value ):
+		key = "/%s_rx"%iface
+		b = int( "%s"%value, 10 )
+		self.myconfig.set_value_count( key, b )
+	
+	def saveByteTX( self, iface, value ):
+		key = "/%s_tx"%iface
+		b = int( "%s"%value, 10 )
+		self.myconfig.set_value_count( key, b )
+
+	def countByteRX( self, iface ):
+		key = "/%s_rx"%iface
+		value = self.myconfig.get_value_count( key )
+		return value
+	
+	def countByteTX( self, iface ):
+		key = "/%s_tx"%iface
+		value = self.myconfig.get_value_count( key )
+		return value
+
+	def setDateReset( self, iface ):
+		key = "/%s_date"%iface
+		d = time.strftime( "%Y-%m-%d %H:%M:%S", time.localtime( time.time() ) ) 
+		self.myconfig.set_value_count( key, d )
+		return d
+	
+	def getDateReset( self, iface ):
+		key = "/%s_date"%iface
+		value = self.myconfig.get_value_count( key )
+		return value
+
+
 	#------- settings --------#
 	def showDialogSelectedIface(self):
 		#self.listShowIfaceTemp = list( self.listShowIface ) #nafih
+		dialog = gtk.Dialog()
 
 		def ifaceButton_changed(ifaceButton):
 			iface = ifaceButton.get_label()
@@ -558,28 +718,61 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 				except ValueError:
 					pass
 
-		dialog = gtk.Dialog()
+		def resetButton_clicked( button ):
+			t = button.get_title()
+			iface = split(t, self.title_button_reset)[1]
+			d = self.setDateReset( "%s"%iface )
+			resetButton.set_value( "rx: 0 B tx: 0 B  date: %s"%(d) )
+			#resetButton.queue_draw()
+			self.saveByteRX( iface, 0 )
+			self.saveByteTX( iface, 0 )
+			hildon.hildon_banner_show_information(self, "None", "Counter is reset on %s"%iface)
+			dialog.hide()
+
 		dialog.set_title("Network interfaces")
 		#dialog.add_button("OK", gtk.RESPONSE_OK)
 		
 		pan_area = hildon.PannableArea()
-		vbox = gtk.VBox()
+		vbox1 = gtk.VBox()
+		vbox2 = gtk.VBox()
+		hbox = gtk.HBox()
 
 		listButtonIfaces = []
 		for iface in self.listIface:
-			ifaceButton = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+
+			ifaceButton = hildon.CheckButton( gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT )
 			ifaceButton.set_label( iface )
 			#img = self.pictureIface( iface )
 			#ifaceButton.set_image( img )
+			flIfaceChecked = False
 			try:
 				indx = self.listShowIfaceTemp.index( iface )
 				ifaceButton.set_active(True)
+				flIfaceChecked = True
 			except ValueError:
 				ifaceButton.set_active(False)
-			ifaceButton.connect("toggled", ifaceButton_changed)
-			vbox.add( ifaceButton )
+			ifaceButton.connect( "toggled", ifaceButton_changed )
+			vbox1.add( ifaceButton )
+			
+			resetButton = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+			resetButton.set_title("Reset the counter of bytes on %s"%iface)
+			rx_count = self.countByteRX( iface )
+			tx_count = self.countByteTX( iface )
+			rx = self.humanBytes( rx_count )
+			tx = self.humanBytes( tx_count )
+			d = self.getDateReset( iface )
+			if d == 0:
+				d = "undefined"
+			resetButton.set_value( "rx: %s  tx: %s  date: %s"%(rx, tx, d) )
+			resetButton.set_alignment(0, 0.8, 0.5, 1)
+			resetButton.connect( "clicked", resetButton_clicked )
+			#resetButton.set_sensitive( flIfaceChecked )
+			vbox2.add( resetButton )
 
-		pan_area.add_with_viewport(vbox)
+		hbox.add( vbox1 )
+		hbox.add( vbox2 )
+
+		pan_area.add_with_viewport(hbox)
 		pan_area.set_size_request(-1, 300)
 
 		dialog.vbox.add(pan_area)
@@ -593,6 +786,7 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		self.netIface_indx = ""
 		self.showIP_local = self.showIP
 		self.showButtonRec_local = self.showButtonRec
+		self.mode_local = self.mode
 
 		def selectorTimeout_changed( selector, data ):
 			self.refreshInterval_indx = selector.get_active(0)
@@ -610,6 +804,13 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 			if self.widgetConnectedWithQNetManDaemon == False:
 				self.widgetConnectedWithQNetManDaemon = self.initConnectionDBus()
 			self.showButtonRec_local = buttonShowRec.get_active()
+		
+		def selectorMode_changed( selector, data ):
+			mode = selector.get_active(0)
+			if mode == 0:
+				self.mode_local = MODE_MONITOR
+			else:
+				self.mode_local = MODE_COUNT
 
 		dialog = gtk.Dialog()
 		dialog.set_title("Settings")
@@ -655,12 +856,29 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 		buttonShowRec.connect( "toggled", show_rec_changed )
 		#------------------------------#
 
+		# ---- opt mode ---- #
+		selectorMode = hildon.TouchSelector(text=True)
+		selectorMode.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
+		for m in self.listModeWidget:
+			selectorMode.append_text( m )
+		selectorMode.connect("changed", selectorMode_changed)
+		wdg_mode = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+		wdg_mode.set_alignment(0.0, 0.5, 1.0, 1.0)
+		wdg_mode.set_title("Mode widget")
+		wdg_mode.set_selector(selectorMode)
+		if self.mode_local == MODE_MONITOR:
+			wdg_mode.set_active( 0 )
+		elif self.mode_local == MODE_COUNT:
+			wdg_mode.set_active( 1 )
+		#------------------------------#
+
 		pan_area = hildon.PannableArea()
 		vbox = gtk.VBox()
 		vbox.add(refreshInterval)
 		vbox.add(nifButton)
 		vbox.add(buttonShowIP)
 		vbox.add(buttonShowRec)
+		vbox.add(wdg_mode)
 
 		pan_area.add_with_viewport(vbox)
 		pan_area.set_size_request(-1, 280)
@@ -701,6 +919,10 @@ class QNetManHomePlugin(hildondesktop.HomePluginItem):
 					#show rec
 					self.showButtonRec = self.showButtonRec_local
 					self.myconfig.set_show_rec( self.showButtonRec_local )
+
+					#mode widget
+					self.mode = self.mode_local
+					self.myconfig.set_mode_widget( self.mode )
 	
 					#reinit the widget
 					self.initHomescreenWidget()
